@@ -148,10 +148,11 @@ main(int argc,char **argv)
   char *rec_dmn_nm=NULL; /* [sng] Record dimension name */
   char *rec_dmn_nm_fix=NULL; /* [sng] Record dimension name (Original input name without _fix prefix) */
   char *rgr_in=NULL; /* [sng] File containing fields to be regridded */
-  char *rgr_out=NULL; /* [sng] File containing regridded fields */
   char *rgr_grd_src=NULL; /* [sng] File containing input grid */
   char *rgr_grd_dst=NULL; /* [sng] File containing destination grid */
+  char *rgr_hrz=NULL; /* [sng] File containing horizontal coordinate grid */
   char *rgr_map=NULL; /* [sng] File containing mapping weights from source to destination grid */
+  char *rgr_out=NULL; /* [sng] File containing regridded fields */
   char *rgr_var=NULL; /* [sng] Variable for special regridding treatment */
   char *rgr_vrt=NULL; /* [sng] File containing vertical coordinate grid */
   char *smr_fl_sz_sng=NULL; /* [sng] String describing estimated file size */
@@ -292,6 +293,7 @@ main(int argc,char **argv)
   nco_bool flg_frac_b_nrm=False; /* [flg] Normalize map-file weights when frac_b >> 1 */
   nco_bool flg_mmr_cln=True; /* [flg] Clean memory prior to exit */
   nco_bool flg_rgr=False; /* [flg] Regrid */
+  nco_bool flg_s1d=False; /* [flg] Unpack sparse-1D CLM/ELM variables */
   nco_bool flg_trr=False; /* [flg] Terraref */
 
   nco_dmn_dne_t *flg_dne=NULL; /* [lst] Flag to check if input dimension -d "does not exist" */
@@ -401,6 +403,9 @@ main(int argc,char **argv)
     {"secret",no_argument,0,0},
     {"shh",no_argument,0,0},
     {"srm",no_argument,0,0}, /* [flg] Print ncStream */
+    {"s1d",no_argument,0,0}, /* [flg] Unpack sparse-1D CLM/ELM variables */
+    {"sparse",no_argument,0,0}, /* [flg] Unpack sparse-1D CLM/ELM variables */
+    {"unpack_sparse",no_argument,0,0}, /* [flg] Unpack sparse-1D CLM/ELM variables */
     {"sysconf",no_argument,0,0}, /* [flg] Perform sysconf() test */
     {"wrt_tmp_fl",no_argument,0,0}, /* [flg] Write output to temporary file */
     {"write_tmp_fl",no_argument,0,0}, /* [flg] Write output to temporary file */
@@ -453,6 +458,9 @@ main(int argc,char **argv)
     {"file_print",required_argument,0,0}, /* [sng] Formatted text output file */
     {"prn_fl",required_argument,0,0}, /* [sng] Formatted text output file */
     {"print_file",required_argument,0,0}, /* [sng] Formatted text output file */
+    {"ccr",required_argument,0,0}, /* [sng] CCR codec name */
+    {"cdc",required_argument,0,0}, /* [sng] CCR codec name */
+    {"codec",required_argument,0,0}, /* [sng] CCR codec name */
     {"flt",required_argument,0,0}, /* [sng] Filter string */
     {"filter",required_argument,0,0}, /* [sng] Filter string */
     {"fmt_val",required_argument,0,0}, /* [sng] Format string for variable values */
@@ -487,8 +495,11 @@ main(int argc,char **argv)
     {"rgr_map",required_argument,0,0}, /* [sng] File containing mapping weights from source to destination grid */
     {"map_file",required_argument,0,0}, /* [sng] File containing mapping weights from source to destination grid */
     {"map_fl",required_argument,0,0}, /* [sng] File containing mapping weights from source to destination grid */
-    {"rgr_var",required_argument,0,0}, /* I [sng] Variable for special regridding treatment */
+    {"rgr_hrz",required_argument,0,0}, /* [sng] File containing horizontal coordinate grid */
+    {"hrz_fl",required_argument,0,0}, /* [sng] File containing horizontal coordinate grid */
+    {"hrz_crd",required_argument,0,0}, /* [sng] File containing horizontal coordinate grid */
     {"rgr_rnr",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
+    {"rgr_var",required_argument,0,0}, /* I [sng] Variable for special regridding treatment */
     {"rgr_vrt",required_argument,0,0}, /* [sng] File containing vertical coordinate grid */
     {"vrt_fl",required_argument,0,0}, /* [sng] File containing vertical coordinate grid */
     {"vrt_crd",required_argument,0,0}, /* [sng] File containing vertical coordinate grid */
@@ -701,7 +712,16 @@ main(int argc,char **argv)
       } /* !fix_rec_dmn */
       if(!strcmp(opt_crr,"fl_fmt") || !strcmp(opt_crr,"file_format")) rcd=nco_create_mode_prs(optarg,&fl_out_fmt);
       if(!strcmp(opt_crr,"fl_prn") || !strcmp(opt_crr,"file_print") || !strcmp(opt_crr,"prn_fl") || !strcmp(opt_crr,"print_file")) fl_prn=(char *)strdup(optarg);
-      if(!strcmp(opt_crr,"flt") || !strcmp(opt_crr,"filter")) flt_sng=(char *)strdup(optarg);
+      if(!strcmp(opt_crr,"flt") || !strcmp(opt_crr,"filter")){
+	flt_sng=(char *)strdup(optarg);
+	/* [fnc] Parse filter string and exit */
+	if(flt_sng) nco_flt_prs(flt_sng);
+      } /* !flt */
+      if(!strcmp(opt_crr,"ccr") || !strcmp(opt_crr,"cdc") || !strcmp(opt_crr,"codec")){
+	nco_flt_glb=nco_flt_sng2enm(optarg);
+	(void)fprintf(stdout,"%s: INFO %s reports user-specified filter string translates to CCR string \"%s\"<.\n",nco_prg_nm,nco_prg_nm,nco_flt_enm2sng((nco_flt_typ_enm)nco_flt_glb_get()));
+	nco_exit(EXIT_SUCCESS);
+      } /* !ccr */
       if(!strcmp(opt_crr,"fmt_val") || !strcmp(opt_crr,"val_fmt") || !strcmp(opt_crr,"value_format")) fmt_val=(char *)strdup(optarg);
       if(!strcmp(opt_crr,"gaa") || !strcmp(opt_crr,"glb_att_add")){
         gaa_arg=(char **)nco_realloc(gaa_arg,(gaa_nbr+1)*sizeof(char *));
@@ -785,6 +805,10 @@ main(int argc,char **argv)
         flg_rgr=True;
 	rgr_map=(char *)strdup(optarg);
       } /* endif rgr_map */
+      if(!strcmp(opt_crr,"hrz_fl") || !strcmp(opt_crr,"hrz_crd") || !strcmp(opt_crr,"rgr_hrz")){
+	flg_s1d=flg_rgr=True;
+	rgr_hrz=(char *)strdup(optarg);
+      } /* !vrt_fl */
       if(!strcmp(opt_crr,"vrt_fl") || !strcmp(opt_crr,"vrt_crd") || !strcmp(opt_crr,"rgr_vrt")){
         flg_rgr=True;
 	rgr_vrt=(char *)strdup(optarg);
@@ -802,6 +826,7 @@ main(int argc,char **argv)
         nco_exit(EXIT_SUCCESS);
       } /* endif "shh" */
       if(!strcmp(opt_crr,"srm")) PRN_SRM=True; /* [flg] Print ncStream */
+      if(!strcmp(opt_crr,"s1d") || !strcmp(opt_crr,"sparse") || !strcmp(opt_crr,"unpack_sparse")) flg_s1d=flg_rgr=True; /* [flg] Unpack sparse-1D CLM/ELM variables */
       if(!strcmp(opt_crr,"sysconf")){
 	long maxrss; /* [B] Maximum resident set size */
 	maxrss=nco_mmr_usg_prn((int)0);
@@ -818,10 +843,10 @@ main(int argc,char **argv)
       if(!strcmp(opt_crr,"tst_udunits")){ 
 	/* Use this feature with, e.g.,
 	   ncks --tst_udunits='5 meters',centimeters ~/nco/data/in.nc
-	   ncks --tst_udunits='days since 1918-11-11','days since 1939-09-09',standard ~/nco/data/in.nc
-	   ncks --tst_udunits='days since 1918-11-11','days since 1939-09-09',360_day ~/nco/data/in.nc
-	   ncks --tst_udunits='days since 1918-11-11','days since 1939-09-09',365_day ~/nco/data/in.nc
-	   ncks --tst_udunits='days since 1918-11-11','days since 1939-09-09',366_day ~/nco/data/in.nc */
+	   ncks --tst_udunits='0 days since 1918-11-11','days since 1939-09-09',standard ~/nco/data/in.nc
+	   ncks --tst_udunits='0 days since 1918-11-11','days since 1939-09-09',360_day ~/nco/data/in.nc
+	   ncks --tst_udunits='0 days since 1918-11-11','days since 1939-09-09',365_day ~/nco/data/in.nc
+	   ncks --tst_udunits='0 days since 1918-11-11','days since 1939-09-09',366_day ~/nco/data/in.nc */
         char *cp;
         char **args;
         double crr_val;
@@ -832,7 +857,7 @@ main(int argc,char **argv)
         cp=strdup(optarg); 
         args=nco_lst_prs_1D(cp,",",&lmt_nbr);         
         nco_cln_clc_dbl_org(args[0],args[1],(lmt_nbr > 2 ? nco_cln_get_cln_typ(args[2]) : cln_nil),&crr_val);        
-        (void)fprintf(stdout,"Units in=%s, units out=%s, difference (date) or conversion (non-date) = %f\n",args[0],args[1],crr_val);
+        (void)fprintf(stdout,"Value+Units in=%s, units out=%s, time-difference (for dates) or value-conversion (for non-dates) = %f\n",args[0],args[1],crr_val);
         if(cp) cp=(char *)nco_free(cp);
         nco_exit(EXIT_SUCCESS);
       } /* endif "tst_udunits" */
@@ -1094,9 +1119,6 @@ main(int argc,char **argv)
 
   if(ALPHABETIZE_OUTPUT) trv_tbl_srt(srt_mth,trv_tbl);
 
-  /* [fnc] Parse filter string and exit */
-  if(flt_sng) nco_flt_prs(flt_sng);
-
   /* [fnc] Print extraction list and exit */
   if(LST_XTR) nco_xtr_lst(trv_tbl);
 
@@ -1196,13 +1218,14 @@ main(int argc,char **argv)
       /* Initialize regridding structure */
       rgr_in=(char *)strdup(fl_in);
       rgr_out=(char *)strdup(fl_out);
-      rgr_nfo=nco_rgr_ini(cmd_ln,in_id,rgr_arg,rgr_nbr,rgr_in,rgr_out,rgr_grd_src,rgr_grd_dst,rgr_map,rgr_var,rgr_vrt,wgt_vld_thr,xtn_lst_in,xtn_nbr);
+      rgr_nfo=nco_rgr_ini(cmd_ln,in_id,rgr_arg,rgr_nbr,rgr_in,rgr_out,rgr_grd_src,rgr_grd_dst,rgr_hrz,rgr_map,rgr_var,rgr_vrt,wgt_vld_thr,xtn_lst_in,xtn_nbr);
       rgr_nfo->fl_out_fmt=fl_out_fmt;
       rgr_nfo->dfl_lvl=dfl_lvl;
       rgr_nfo->hdr_pad=hdr_pad;
+      rgr_nfo->flg_area_out=EXTRACT_CLL_MSR; /* [flg] Add area to output */
+      rgr_nfo->flg_s1d=flg_s1d; /* [flg] Unpack sparse-1D CLM/ELM variables */
       rgr_nfo->flg_uio=SHARE_CREATE;
       rgr_nfo->fl_out_tmp=nco_fl_out_open(rgr_nfo->fl_out,&FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,SHARE_CREATE,SHARE_OPEN,WRT_TMP_FL,&out_id);
-      if(EXTRACT_CLL_MSR) rgr_nfo->flg_area_out=True; else rgr_nfo->flg_area_out=False; /* [flg] Add area to output */
 
       /* Copy Global Metadata */
       rgr_nfo->out_id=out_id;
