@@ -240,6 +240,7 @@ extern "C" {
   char *nco_not_mss_val_sng_get(void); /* [sng] Not missing value attribute name */
   char *nco_prg_nm_get(void);
   int nco_prg_id_get(void);
+  int nco_flt_glb_get(void);
   unsigned short nco_baa_cnv_get(void);
   unsigned short nco_bnr_cnv_get(void);
   unsigned short nco_dbg_lvl_get(void);
@@ -275,6 +276,9 @@ extern "C" {
   unsigned short nco_dbg_lvl=0; /* [enm] Debugging level */
   unsigned short nco_dbg_lvl_get(void){return nco_dbg_lvl;} /* [enm] Debugging level */
 
+  int nco_flt_glb=0; /* [enm] Filter enum */
+  int nco_flt_glb_get(void){return nco_flt_glb;} /* [enm] Filter enum */
+
   unsigned short nco_fmt_xtn=0; /* [enm] Extended file format */
   unsigned short nco_fmt_xtn_get(void){return nco_fmt_xtn;} /* [enm] Extended file format */
   void nco_fmt_xtn_set(unsigned short nco_fmt_xtn_arg){nco_fmt_xtn=nco_fmt_xtn_arg;} /* [enm] Extended file format */
@@ -352,7 +356,7 @@ extern "C" {
 # define NCO_VERSION_MINOR 9
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 5
+# define NCO_VERSION_PATCH 7
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
@@ -362,7 +366,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.9.5"
+# define NCO_VERSION "4.9.7"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -866,7 +870,7 @@ extern "C" {
     nco_bool is_usr_spc_max; /* True if user-specified, else False */
     nco_bool is_usr_spc_min; /* True if user-specified, else False */
 
-    nco_cln_typ lmt_cln; /* Used by ncra, ncrcat to store enum of calendar-type attribute */
+    nco_cln_typ cln_typ; /* Used by ncra, ncrcat to store enum of calendar-type attribute */
 
   } lmt_sct;
   
@@ -1037,15 +1041,6 @@ extern "C" {
     nco_bool PRN_CLN_LGB; /* [flg] Print UDUnits-formatted calendar dates/times human-legibly */
   } prn_fmt_sct;
   
-  /* Types used in Terraref structure */
-  typedef enum nco_trr_ntl_typ_enm{ /* [enm] Interleave-type enum */
-    nco_trr_ntl_nil=0,
-    nco_trr_ntl_unk, /* Unknown or unclassified interleave-type */ 
-    nco_trr_ntl_bsq, /* Band Sequential */
-    nco_trr_ntl_bip, /* Band-interleaved-by-pixel */
-    nco_trr_ntl_bil, /* Band-interleaved-by-line */
-  } nco_trr_ntl_typ_enm;
-
   /* Types used in regrid structure */
   typedef enum nco_grd_2D_typ_enm{ /* [enm] Two-dimensional grid-type enum */
     nco_grd_2D_nil=0,
@@ -1134,41 +1129,13 @@ typedef enum nco_xtr_typ_enm
     nco_bool crd; /* [flg] CF coordinates information is complete */
   } cf_crd_sct; /* end CF coordinates structure */
 
-  /* Terraref structure */
-  typedef struct{ /* trr_sct */
-    // File names specifiable with individual command line switches
-    char *fl_in; /* [sng] File containing raw imagery */
-    char *fl_out; /* [sng] File containing netCDF imagery */
-    char *fl_out_tmp; /* [sng] Temporary file containing netCDF imagery */
-    // Metadata specifiable with key-value syntax
-    char **trr_arg; /* [sng] Terraref arguments */
-    char *wvl_nm; /* [sng] Name of wavelength dimension */
-    char *xdm_nm; /* [sng] Name of x-coordinate dimension */
-    char *ydm_nm; /* [sng] Name of y-coordinate dimension */
-    char *var_nm; /* [sng] Variable containing imagery */
-    char *wvl_bnd_nm; /* [sng] Name of dimension to employ for wavelength bounds */
-    char *xdm_bnd_nm; /* [sng] Name of dimension to employ for x-coordinate bounds */
-    char *ydm_bnd_nm; /* [sng] Name of dimension to employ for y-coordinate bounds */
-    long wvl_nbr; /* [nbr] Number of wavelengths */
-    long xdm_nbr; /* [nbr] Number of pixels in x-dimension */
-    long ydm_nbr; /* [nbr] Number of pixels in y-dimension */
-    nc_type var_typ_in; /* [enm] NetCDF type */
-    nc_type var_typ_out; /* [enm] NetCDF type */
-    // Other internal data and metadata 
-    char *cmd_ln; /* [sng] Command-line */
-    char *ttl; /* [sng] Title */
-    int dfl_lvl; /* [enm] Deflate level [0..9] */
-    int trr_nbr; /* [nbr] Number of Terraref arguments */
-    nco_trr_ntl_typ_enm ntl_typ_in; /* [enm] Interleave-type of raw data */
-    nco_trr_ntl_typ_enm ntl_typ_out; /* [enm] Interleave-type or output */
-  } trr_sct; /* end Terraref structure */
-
   /* Regrid structure */
   typedef struct{ /* rgr_sct */
     // File names specifiable with individual command line switches
     char *drc_tps; /* [sng] Data directory for Tempest grids, meshes, and weights */
     char *fl_grd_src; /* [sng] File containing input grid */
     char *fl_grd_dst; /* [sng] File containing destination grid */
+    char *fl_hrz; /* [sng] File containing horizontal coordinate grid */
     char *fl_in; /* [sng] File containing fields to be regridded */
     char *fl_out; /* [sng] File containing regridded fields */
     char *fl_out_tmp; /* [sng] Temporary file containing regridded fields */
@@ -1259,6 +1226,7 @@ typedef enum nco_xtr_typ_enm
     nco_bool flg_msk_out; /* [flg] Add mask to output */
     nco_bool flg_nfr; /* [flg] Infer SCRIP-format grid file */
     nco_bool flg_rnr; /* [flg] Renormalize destination values by valid area */
+    nco_bool flg_s1d; /* [flg] Unpack sparse-1D CLM/ELM variables */
     nco_bool flg_stg; /* [flg] Write staggered grid with FV output */
     nco_bool flg_uio; /* [flg] Unbuffered I/O (NC_SHARE) for netCDF3 files */
     nco_bool flg_usr_rqs; /* [flg] User-requested regridding */
