@@ -9,6 +9,92 @@
 
 #include "nco_cnv_csm.h" /* CCM/CCSM/CF conventions */
 
+int /* O [rcd] Return code */
+nco_clm_nfo_get /* [fnc] Parse clm_nfo arguments and merge into structure */
+(const char *clm_nfo_sng, /* I [sng] Climatology information string */
+ clm_bnd_sct *cb) /* I/O [sct] Climatology bounds structure */
+{
+  const char fnc_nm[]="nco_clm_nfo_get()"; /* [sng] Function name */
+
+  const char dlm_sng[]=",";
+
+  char **arg_lst;
+
+  char *msg_sng=NULL_CEWI; /* [sng] Error message */
+  char *sng_cnv_rcd=NULL_CEWI; /* [sng] strtol()/strtoul() return code */
+
+  int arg_nbr;
+
+  nco_bool NCO_SYNTAX_ERROR=False; /* [flg] Syntax error in hyperslab specification */
+
+  /* Purpose: Parse user-supplied climatology bounds arguments from clm_nfo_sng and 
+     merge results into climatolgoy bounds (cb) structure */
+  arg_lst=nco_lst_prs_2D(clm_nfo_sng,dlm_sng,&arg_nbr);
+  
+  /* Check syntax */
+  if(arg_nbr < 2){ /* Need more than just dimension name */
+    msg_sng=strdup("Climatology information must specify at least six arguments (the first argument is the start year, the second is the end year, etc.)");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr > 7){ /* Too much information */
+    msg_sng=strdup("Too many (more than 7) arguments in climatology information string");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_lst[0] == NULL){ /* Start year not specified */
+    msg_sng=strdup("Start year not specified");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr == 2 && arg_lst[1] == NULL){ /* End year not specified */
+    msg_sng=strdup("End year not specified");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr == 3 && arg_lst[2] == NULL){ /* Start month not specified */
+    msg_sng=strdup("Start month not specified");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr == 4 && arg_lst[3] == NULL){ /* End month not specified */
+    msg_sng=strdup("End month not specified");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr == 5 && arg_lst[4] == NULL){ /* Timesteps per day not specified */
+    msg_sng=strdup("Timesteps per day not specified");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr == 6 && arg_lst[5] == NULL){ /* Units string not specified */
+    msg_sng=strdup("Units string not specified");
+    NCO_SYNTAX_ERROR=True;
+  }else if(arg_nbr == 7 && arg_lst[6] == NULL){ /* Calendar string not specified */
+    msg_sng=strdup("Calendar string not specified");
+    NCO_SYNTAX_ERROR=True;
+  } /* end else */
+  
+  if(NCO_SYNTAX_ERROR){
+    (void)fprintf(stdout,"%s: ERROR parsing climatolgy bounds information from \"%s\": %s\n%s: HINT Conform request to hyperslab documentation at http://nco.sf.net/nco.html#hyp\n",nco_prg_nm_get(),clm_nfo_sng,msg_sng,nco_prg_nm_get());
+    msg_sng=(char *)nco_free(msg_sng);
+    nco_exit(EXIT_FAILURE);
+  } /* !NCO_SYNTAX_ERROR */
+
+  if(arg_lst[0]){
+    cb->yr_srt=strtol(arg_lst[0],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[0],"strtol",sng_cnv_rcd);
+  } /* !arg_lst[0] */    
+  if(arg_lst[1]){
+    cb->yr_end=strtol(arg_lst[1],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[1],"strtol",sng_cnv_rcd);
+  } /* !arg_lst[1] */    
+  if(arg_lst[2]){
+    cb->mth_srt=strtol(arg_lst[2],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[2],"strtol",sng_cnv_rcd);
+  } /* !arg_lst[2] */    
+  if(arg_lst[3]){
+    cb->mth_end=strtol(arg_lst[3],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[3],"strtol",sng_cnv_rcd);
+  } /* !arg_lst[3] */    
+  if(arg_lst[4]){
+    cb->tpd=strtol(arg_lst[4],&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+    if(*sng_cnv_rcd) nco_sng_cnv_err(arg_lst[4],"strtol",sng_cnv_rcd);
+  } /* !arg_lst[4] */    
+  //if(arg_lst[5]) cb->unt_val=arg_lst[5];
+  //if(arg_lst[6]) cb->cln_val=arg_lst[6];
+    
+  if(nco_dbg_lvl_get() >= nco_dbg_fl) (void)fprintf(stdout,"%s: DEBUG %s reports variable climatology bounds structure elements yr_srt=%d, yr_end=%d, mth_srt=%d, mth_end=%d, tpd=%d, unt_val=%s, cln_val=%s\n",nco_prg_nm_get(),fnc_nm,cb->yr_srt,cb->yr_end,cb->mth_srt,cb->mth_end,cb->tpd,cb->unt_val,cb->cln_val);
+
+  return NCO_NOERR;
+} /* !nco_clm_nfo_get() */
+
 cnv_sct * /* O [sct] Convention structure */
 nco_cnv_ini /* O [fnc] Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating file */
 (const int nc_id) /* I [id] netCDF file ID */
@@ -16,7 +102,7 @@ nco_cnv_ini /* O [fnc] Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating
   /* Purpose: Determine conventions (ARM/CCM/CCSM/CF/MPAS) for treating file
      Based-on and supercedes nco_cnv_ccm_ccsm_cf_inq() */
 
-  //  const char fnc_nm[]="nco_cnv_ini()"; /* [sng] Function name */
+  // const char fnc_nm[]="nco_cnv_ini()"; /* [sng] Function name */
 
   char *att_val;
   char *cnv_sng=NULL_CEWI;
@@ -376,8 +462,13 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
   dmn_mch=(int *)nco_calloc(dmn_nbr_rdc,sizeof(int));
 
   if(cb){
-    if(cb->bnd2clm || cb->clm2clm) cll_mth_clm=strdup("time: mean within years time: mean over years");
-    if(cb->clm2bnd) cll_mth_clm=strdup("time: mean");
+    if(cb->tpd > 1) cll_mth_clm=strdup("time: mean within days time: mean within years time: mean over years");
+    else if(cb->bnd2clm || cb->clm2clm) cll_mth_clm=strdup("time: mean within years time: mean over years");
+    else if(cb->clm2bnd) cll_mth_clm=strdup("time: mean");
+    else{
+      (void)fprintf(stdout,"%s: ERROR %s reports climatology bounds error with variable %s\n",nco_prg_nm_get(),fnc_nm,var_trv->nm);
+      nco_exit(EXIT_FAILURE);
+    } /* !cb->tpd */
   } /* !cb */
 
   /* Process all variables */
@@ -405,6 +496,8 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
     dmn_nbr_mch=0;
     flg_dpl=False;
 
+    if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: DEBUG %s reports variable %s has cll_mth_clm = %s\n",nco_prg_nm_get(),fnc_nm,var_trv->nm,cll_mth_clm);
+
     if(cb){
       /* Does variable use time coordinate? */
       for(dmn_idx_var=0;dmn_idx_var<var_trv->nbr_dmn;dmn_idx_var++)
@@ -416,6 +509,8 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
 	aed.type=NC_CHAR;
 	aed.val.cp=att_val;
 	aed.mode=aed_overwrite;
+	/* Do not add cell_methods to time bounds variables, and delete them if they exist */
+	if(var_out_id == cb->clm_bnd_id_out || var_out_id == cb->tm_bnd_id_out) aed.mode=aed_delete;
 	(void)nco_aed_prc(grp_out_id,var_out_id,aed);
 	if(att_val) att_val=(char *)nco_free(att_val);
 	continue;
@@ -521,8 +616,16 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
 	 cell_methods = "time: mean within years time: mean over years"
 	 Three-step methods (e.g., climatological MAM) should have climatology-bounds attribute
 	 cell_methods = "time: mean within years time: mean over years"
-	 Four-step methods (e.g., climatological ANN) should have time-bounds attribute
-	 cell_methods = "time: mean" */
+	 Four-step methods (e.g., climatological ANN) with one timestep should have time-bounds attribute
+	 cell_methods = "time: mean"
+	 20200809:
+	 http://cfconventions.org/Data/cf-conventions/cf-conventions-1.8/cf-conventions.html#climatological-statistics Example 7.13
+	 Two-step methods with multiple timesteps (e.g., climatological diurnal cycle for March) should have climatology-bounds attribute
+	 cell_methods = "time: cell_methods="time: mean within days time: mean over days time: mean over years";
+	 Three-step methods with multiple timesteps (e.g., climatological diurnal cycle for MAM) should have climatology-bounds attribute
+	 cell_methods = "time: cell_methods="time: mean within days time: mean over days time: mean over years";
+	 Four-step methods with multiple timesteps (e.g., climatological diurnal cycle for ANN) should have climatology-bounds attribute
+	 cell_methods = "time: cell_methods="time: mean within days time: mean over years"; */
       ptr_unn val_old; /* [sng] Old cell_methods attribute */
       val_old.vp=(void *)nco_malloc((att_lng+1L)*sizeof(char));
       (void)nco_get_att(grp_out_id,var_out_id,aed.att_nm,val_old.vp,NC_CHAR);
@@ -550,7 +653,7 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
 
     /* 20150308 */
     /* Does variable already have "coordinates" attribute?
-       NB: This reuses att_nm which has only enough space to hold "cell_methods" */
+       NB: This re-uses att_nm which has only enough space to hold "cell_methods" */
     strcpy(aed.att_nm,"coordinates");
     rcd=nco_inq_att_flg(grp_out_id,var_out_id,aed.att_nm,&att_typ,&att_lng);
     if(rcd == NC_NOERR && att_typ == NC_CHAR){
@@ -614,7 +717,6 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
   if(dmn_mch) dmn_mch=(int *)nco_free(dmn_mch);
 
   return NC_NOERR;
-
 } /* end nco_cnv_cf_cll_mth_add() */
 
 int
