@@ -156,6 +156,12 @@ nco_xtr_xcl                          /* [fnc] Convert extraction list to exclusi
  nco_bool GRP_XTR_VAR_XCL, /* [flg] Extract matching groups, exclude matching variables */
  trv_tbl_sct * const trv_tbl); /* I/O [sct] GTT (Group Traversal Table) */
 
+void
+nco_xtr_xcl_chk /* [fnc] Convert extraction list to exclusion list */
+(char ** var_lst_in, /* I [sng] User-specified list of variables */
+ const int var_xtr_nbr, /* I [nbr] Number of variables in list */
+ trv_tbl_sct * const trv_tbl); /* I [sct] GTT (Group Traversal Table) */
+
 void
 nco_xtr_crd_add                       /* [fnc] Add all coordinates to extraction list */
 (trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
@@ -420,6 +426,13 @@ nco_var_typ_trv                        /* [fnc] Transfer variable type into GTT
  CST_X_PTR_CST_PTR_CST_Y(var_sct,var), /* I [sct] Array of extracted variables */
  trv_tbl_sct * const trv_tbl);         /* I/O [sct] Traversal table */
 
+void
+nco_set_prm_typ_out /* [fnc] Set GTT variable output type to unpacked, arithmetically promoted type for integers */
+(nco_bool const PROMOTE_INTS, /* I/O [flg] Promote integers to floating point in output */
+ const int prc_nbr, /* I [nbr] Number of processed variables */
+ CST_X_PTR_CST_PTR_CST_Y(var_sct,var), /* I [sct] Array of extracted variables */
+ trv_tbl_sct * const trv_tbl); /* I/O [sct] Traversal table */
+
 var_sct *                              /* O [sct] Variable structure */
 nco_var_fll_trv                        /* [fnc] Allocate variable structure and fill with metadata */
 (const int nc_id,                      /* I [id] netCDF file ID */
