@@ -317,6 +317,12 @@ const char * /* O [sng] Native Fortran90 type */
 f90_typ_nm /* [fnc] Return string describing native Fortran90 type */
 (const nc_type type); /* I [enm] netCDF type */
 
+void
+nco_dfl_case_generic_err(void); /* [fnc] Print error and exit for illegal switch case */
+
+void
+nco_dfl_case_flt_err(void); /* [fnc] Print error and exit for illegal switch(nco_flt_enm) case */
+
 void 
 nco_dfl_case_nc_type_err /* [fnc] Print error and exit for illegal switch(nc_type) case */
 (void);
@@ -325,9 +331,6 @@ void
 nco_dfl_case_prg_id_err /* [fnc] Print error and exit for illegal switch(prg_id) case */
 (void);
 
-void
-nco_dfl_case_generic_err(void); /* [fnc] Print error and exit for illegal switch case */
-
 void
 nco_sng_cnv_err /* [fnc] Print error and exit for failed strtol()-type calls */
 (const char *cnv_sng, /* I [sng] String to convert */
@@ -507,7 +510,7 @@ int nco_def_var(const int nc_id,const char * const var_nm,const nc_type var_typ,
 int nco_def_var_chunking(const int nc_id,const int var_id,const int srg_typ,const size_t * const cnk_sz);
 int nco_def_var_deflate(const int nc_id,const int var_id,const int shuffle,const int deflate,const int dfl_lvl);
 int nco_def_var_filter(const int nc_id,const int var_id,const unsigned int flt_id,const size_t prm_nbr,const unsigned int *prm_lst);
-int nco_def_var_filterx(const int nc_id,const int var_id,const char * const flt_nm,const size_t prm_nbr,const char ** const prm_lst);
+int nco_def_var_filter_ccr(const int nc_id,const int var_id,const char * const flt_nm,const size_t prm_nbr,const char ** const prm_lst);
 int nco_def_var_fletcher32(const int nc_id,const int var_id,const int chk_typ);
 int nco_inq_var(const int nc_id,const int var_id,char * const var_nm,nc_type * const var_typ,int * const dmn_nbr,int * const dmn_id,int * const att_nbr);
 int nco_inq_var_chunking(const int nc_id,const int var_id,int * const srg_typ,size_t * const cnk_sz);
@@ -516,9 +519,8 @@ int nco_inq_var_endian(const int nc_id,const int var_id,int * const ndn_typ);
 int nco_inq_var_fill(const int nc_id,const int var_id,int * const fll_nil,void * const fll_val);
 int nco_inq_var_filter(const int nc_id,const int var_id,unsigned int * const flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
 int nco_inq_var_filter_flg(const int nc_id,const int var_id,unsigned int * const flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
-int nco_inq_var_filterids(const int nc_id,const int var_id,size_t * const flt_nbr,unsigned int * const flt_lst);
+int nco_inq_var_filter_ids(const int nc_id,const int var_id,size_t * const flt_nbr,unsigned int * const flt_lst);
 int nco_inq_var_filter_info(const int nc_id,const int var_id,const unsigned int flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
-int nco_var_filter_remove(const int nc_id,const int var_id,const unsigned int flt_id);
 int nco_inq_var_fletcher32(const int nc_id,const int var_id,int * const chk_typ);
 int nco_inq_var_packing(const int nc_id,const int var_id,int * const packing);
 int nco_inq_vardimid(const int nc_id,const int var_id,int * const dmn_id);
@@ -596,15 +598,15 @@ int nco_get_att(const int nc_id,const int var_id,const char * const att_nm,void
   int nc_inq_var_filter(const int nc_id,const int var_id,unsigned int * const flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
 #endif /* !4.6.0 */
 
+#if NC_LIB_VERSION == 474
+# define nc_inq_var_filter_ids nc_inq_var_filterids
+#endif /* !4.7.4 */
 #if NC_LIB_VERSION < 474
-  int nc_inq_var_filterids(const int nc_id,const int var_id,size_t * const flt_nbr,unsigned int * const flt_lst);
+  int nc_inq_var_filter_ids(const int nc_id,const int var_id,size_t * const flt_nbr,unsigned int * const flt_lst);
   int nc_inq_var_filter_info(const int nc_id,const int var_id,const unsigned int flt_id,size_t * const prm_nbr,unsigned int * const prm_lst);
-  int nc_var_filter_remove(const int nc_id,const int var_id,const unsigned int flt_id);
 #endif /* !4.7.4 */
 
-#if NC_LIB_VERSION < 480
-  int nc_def_var_filterx(const int nc_id,const int var_id,const char * const flt_nm,const size_t prm_nbr,const char ** const prm_lst);
-#endif /* !4.8.0 */
+  int nc_def_var_filter_ccr(const int nc_id,const int var_id,const char * const flt_nm,const size_t prm_nbr,const char ** const prm_lst);
 
   /* Begin netCDF4 stubs */
 #ifndef HAVE_NETCDF4_H
