@@ -564,7 +564,7 @@ KDPriority *list){
 }
 
 poly_sct **
-nco_poly_lst_mk_vrl(   /* create overlap mesh  for crt polygons */
+nco_poly_lst_mk_vrl_crt(   /* create overlap mesh  for crt polygons */
 poly_sct **pl_lst_in,
 int pl_cnt_in,
 KDTree *rtree,
@@ -580,7 +580,7 @@ int *pl_cnt_vrl_ret){
 
   //nco_bool bSort=True;
 
-  const char fnc_nm[]="nco_poly_mk_vrl()";
+  const char fnc_nm[]="nco_poly_mk_vrl_crt()";
 
   /* buffers  used in nco-poly_re_org() */
   double lcl_dp_x[VP_MAX]={0};
@@ -686,16 +686,17 @@ int *pl_cnt_vrl_ret){
 
 
 void **
-nco_poly_lst_mk_vrl_sph(  /* create overlap mesh  for sph polygons */
+nco_poly_lst_mk_vrl(  /* create overlap mesh  for sph polygons */
 poly_sct **pl_lst_in,
 int pl_cnt_in,
 nco_grd_lon_typ_enm grd_lon_typ,
+poly_typ_enm pl_typ,
 KDTree **tree,
 int nbr_tr,
 int lst_out_typ,
 int *pl_cnt_vrl_ret){
   /* just duplicate output list to overlap */
-  const char fnc_nm[]="nco_poly_lst_mk_vrl_sph()";
+  const char fnc_nm[]="nco_poly_lst_mk_vrl()";
 
   nco_bool bDirtyRats=False;
   nco_bool bSort=True;
@@ -713,7 +714,7 @@ int *pl_cnt_vrl_ret){
   /* reporting step */
   int thr_quota_step;
 
-  poly_typ_enm pl_typ;
+
   size_t idx;
 
   int lcl_thr_nbr;
@@ -728,9 +729,7 @@ int *pl_cnt_vrl_ret){
   poly_sct** pl_lst_dbg=NULL_CEWI;
 
   FILE * const fp_stderr=stderr;
-
-
-  pl_typ=pl_lst_in[0]->pl_typ;
+  
 
 
   lcl_thr_nbr=omp_get_max_threads();
@@ -797,7 +796,7 @@ int *pl_cnt_vrl_ret){
 
 
     if(pl_lst_in[idx]->bmsk==False)
-      continue;
+      goto cont_msk;  /* need to iterate mem_lst diagnostics at end of loop*/
 
     mem_lst[thr_idx].kd_cnt=0;
 
@@ -1185,6 +1184,8 @@ int *pl_cnt_vrl_ret){
 
     } /* end dbg */
 
+    cont_msk: ;
+
     /* output some usefull tracking stuff - not debug but informative */
     if (  ++mem_lst[thr_idx].idx_cnt % thr_quota_step == 0 && nco_dbg_lvl_get() >=3   )
       (void)fprintf(fp_stderr, "%s: thread %d  has processed %2.2f%% (%ld) of src cells quota and output %ld overlap cells\n",    nco_prg_nm_get(), thr_idx, (float)mem_lst[thr_idx].idx_cnt/(float)thr_quota *100.0,  mem_lst[thr_idx].idx_cnt, mem_lst[thr_idx].pl_cnt  );
